@@ -5,7 +5,7 @@ import urllib.parse
 import urllib.request
 
 # https://api.github.com/search/issues?q=repo:rdflib/rdflib+is:pr+merged:%3E=2023-08-02&per_page=300&page=1
-LAST_RELEASE_DATE = "2024-10-17"
+LAST_RELEASE_DATE = "2025-03-29"
 ISSUES_URL = "https://api.github.com/search/issues"
 ITEMS = []
 PAGE = 1
@@ -23,7 +23,11 @@ while True:
     print(f"Getting {url}")
     with urllib.request.urlopen(url) as response:
         response_text = response.read()
-        link_headers = response.info()["link"].split(",") if response.info()["link"] is not None else None
+        link_headers = (
+            response.info()["link"].split(",")
+            if response.info()["link"] is not None
+            else None
+        )
 
     json_data = json.loads(response_text)
     ITEMS.extend(json_data["items"])
