@@ -15,6 +15,7 @@ Example 2: larger data
 * loads multiple graphs downloaded from GitHub into a BerkeleyDB-baked graph stored in the folder gsq_vocabs.
 * does not delete the DB at the end so you can see it on disk
 """
+
 import os
 import tempfile
 
@@ -46,7 +47,7 @@ def example_1():
     print("(will always be 0 when using temp file for DB)")
 
     # Now we'll add some triples to the graph & commit the changes
-    EG = Namespace("http://example.net/test/")
+    EG = Namespace("http://example.net/test/")  # noqa: N806
     graph.bind("eg", EG)
 
     graph.add((EG["pic:1"], EG.name, Literal("Jane & Bob")))
