@@ -11,11 +11,10 @@ if TYPE_CHECKING:
 __all__ = ["Collection"]
 
 
-class Collection(object):
-    __doc__ = """
-    See "Emulating container types":
-    https://docs.python.org/reference/datamodel.html#emulating-container-types
+class Collection:
+    """See "Emulating container types": <https://docs.python.org/reference/datamodel.html#emulating-container-types>
 
+    ```python
     >>> from rdflib.term import Literal
     >>> from rdflib.graph import Graph
     >>> from pprint import pprint
@@ -37,10 +36,9 @@ class Collection(object):
     <Graph identifier=... (<class 'rdflib.graph.Graph'>)>
     >>> c = Collection(g,listname)
     >>> pprint([term.n3() for term in c])
-    [u'"1"^^<http://www.w3.org/2001/XMLSchema#integer>',
-     u'"2"^^<http://www.w3.org/2001/XMLSchema#integer>',
-     u'"3"^^<http://www.w3.org/2001/XMLSchema#integer>']
-
+    ['"1"^^<http://www.w3.org/2001/XMLSchema#integer>',
+     '"2"^^<http://www.w3.org/2001/XMLSchema#integer>',
+     '"3"^^<http://www.w3.org/2001/XMLSchema#integer>']
     >>> Literal(1) in c
     True
     >>> len(c)
@@ -49,15 +47,21 @@ class Collection(object):
     True
     >>> c.index(Literal(2)) == 1
     True
+
+    ```
+
+    The collection is immutable if `uri` is the empty list (`http://www.w3.org/1999/02/22-rdf-syntax-ns#nil`).
     """
 
     def __init__(self, graph: Graph, uri: Node, seq: List[Node] = []):
         self.graph = graph
         self.uri = uri or BNode()
-        self += seq
+        if seq:
+            self += seq
 
     def n3(self) -> str:
         """
+        ```python
         >>> from rdflib.term import Literal
         >>> from rdflib.graph import Graph
         >>> listname = BNode()
@@ -79,11 +83,12 @@ class Collection(object):
         >>> c = Collection(g, listname)
         >>> print(c.n3()) #doctest: +NORMALIZE_WHITESPACE
         ( "1"^^<http://www.w3.org/2001/XMLSchema#integer>
-          "2"^^<http://www.w3.org/2001/XMLSchema#integer>
-          "3"^^<http://www.w3.org/2001/XMLSchema#integer> )
+            "2"^^<http://www.w3.org/2001/XMLSchema#integer>
+            "3"^^<http://www.w3.org/2001/XMLSchema#integer> )
+
+        ```
         """
-        # type error: "Node" has no attribute "n3"
-        return "( %s )" % (" ".join([i.n3() for i in self]))  # type: ignore[attr-defined]
+        return "( %s )" % (" ".join([i.n3() for i in self]))
 
     def _get_container(self, index: int) -> Optional[Node]:
         """Gets the first, rest holding node at index."""
@@ -144,6 +149,7 @@ class Collection(object):
 
     def __delitem__(self, key: int) -> None:
         """
+        ```python
         >>> from rdflib.namespace import RDF, RDFS
         >>> from rdflib import Graph
         >>> from pprint import pformat
@@ -184,6 +190,7 @@ class Collection(object):
         >>> len(g)
         4
 
+        ```
         """
         self[key]  # to raise any potential key exceptions
         graph = self.graph
@@ -220,6 +227,7 @@ class Collection(object):
 
     def append(self, item: Node) -> Collection:
         """
+        ```python
         >>> from rdflib.term import Literal
         >>> from rdflib.graph import Graph
         >>> listname = BNode()
@@ -230,9 +238,12 @@ class Collection(object):
         >>> len([i for i in links if (i, RDF.rest, RDF.nil) in g])
         1
 
+        ```
         """
-
         end = self._end()
+        if end == RDF.nil:
+            raise ValueError("Cannot append to empty list")
+
         if (end, RDF.first, None) in self.graph:
             # append new node to the end of the linked list
             node = BNode()
@@ -245,6 +256,8 @@ class Collection(object):
 
     def __iadd__(self, other: Iterable[Node]):
         end = self._end()
+        if end == RDF.nil:
+            raise ValueError("Cannot append to empty list")
         self.graph.remove((end, RDF.rest, None))
 
         for item in other:
