@@ -83,6 +83,7 @@ __all__ = [
     "Formula",
     "RDFSink",
     "SinkParser",
+    "sfloat",
 ]
 
 from rdflib.parser import Parser
@@ -94,18 +95,18 @@ _AnyT = TypeVar("_AnyT")
 
 
 def splitFragP(uriref: str, punc: int = 0) -> Tuple[str, str]:
-    """split a URI reference before the fragment
+    """Split a URI reference before the fragment
 
-    Punctuation is kept.
-
-    e.g.
+    Punctuation is kept. e.g.
 
+    ```python
     >>> splitFragP("abc#def")
     ('abc', '#def')
 
     >>> splitFragP("abcdef")
     ('abcdef', '')
 
+    ```
     """
 
     i = uriref.rfind("#")
@@ -123,15 +124,19 @@ def join(here: str, there: str) -> str:
     (non-ascii characters are supported/doctested;
     haven't checked the details of the IRI spec though)
 
-    ``here`` is assumed to be absolute.
-    ``there`` is URI reference.
+    `here` is assumed to be absolute.
+    `there` is URI reference.
 
+    ```python
     >>> join('http://example/x/y/z', '../abc')
     'http://example/x/abc'
 
+    ```
+
     Raise ValueError if there uses relative path
     syntax but here has no hierarchical path.
 
+    ```python
     >>> join('mid:foo@example', '../foo') # doctest: +NORMALIZE_WHITESPACE
     Traceback (most recent call last):
         raise ValueError(here)
@@ -144,13 +149,18 @@ def join(here: str, there: str) -> str:
     >>> join('mid:foo@example', '#foo')
     'mid:foo@example#foo'
 
+    ```
+
     We grok IRIs
 
+    ```python
     >>> len('Andr\\xe9')
     5
 
     >>> join('http://example.org/', '#Andr\\xe9')
     'http://example.org/#Andr\\xe9'
+
+    ```
     """
 
     #    assert(here.find("#") < 0), \
@@ -223,7 +233,6 @@ def base() -> str:
     this yield the URI of the file.
     If we had a reliable way of getting a computer name,
     we should put it in the hostname just to prevent ambiguity
-
     """
     # return "file://" + hostname + os.getcwd() + "/"
     return "file://" + _fixslash(os.getcwd()) + "/"
@@ -380,6 +389,10 @@ interesting = re.compile(r"""[\\\r\n\"\']""")
 langcode = re.compile(r"[a-zA-Z0-9]+(-[a-zA-Z0-9]+)*")
 
 
+class sfloat(str):  # noqa: N801
+    """don't normalize raw XSD.double string representation"""
+
+
 class SinkParser:
     def __init__(
         self,
@@ -541,7 +554,7 @@ class SinkParser:
         we must not be at end of file.
 
         if colon, then keyword followed by colon is ok
-        (@prefix:<blah> is ok, rdf:type shortcut a must be followed by ws)
+        (`@prefix:<blah>` is ok, rdf:type shortcut a must be followed by ws)
         """
 
         assert tok[0] not in _notNameChars  # not for punctuation
@@ -1528,7 +1541,7 @@ class SinkParser:
                 m = exponent_syntax.match(argstr, i)
                 if m:
                     j = m.end()
-                    res.append(float(argstr[i:j]))
+                    res.append(sfloat(argstr[i:j]))
                     return j
 
                 m = decimal_syntax.match(argstr, i)
@@ -1911,7 +1924,7 @@ class RDFSink:
     def normalise(
         self,
         f: Optional[Formula],
-        n: Union[Tuple[int, str], bool, int, Decimal, float, _AnyT],
+        n: Union[Tuple[int, str], bool, int, Decimal, sfloat, _AnyT],
     ) -> Union[URIRef, Literal, BNode, _AnyT]:
         if isinstance(n, tuple):
             return URIRef(str(n[1]))
@@ -1931,7 +1944,7 @@ class RDFSink:
             s = Literal(value, datatype=DECIMAL_DATATYPE)
             return s
 
-        if isinstance(n, float):
+        if isinstance(n, sfloat):
             s = Literal(str(n), datatype=DOUBLE_DATATYPE)
             return s
 
@@ -1947,7 +1960,7 @@ class RDFSink:
         #    f.universals[n] = f.newBlankNode()
         #    return f.universals[n]
         # type error: Incompatible return value type (got "Union[int, _AnyT]", expected "Union[URIRef, Literal, BNode, _AnyT]")  [return-value]
-        return n  # type: ignore[return-value]
+        return n
 
     def intern(self, something: _AnyT) -> _AnyT:
         return something
@@ -1972,9 +1985,11 @@ def hexify(ustr: str) -> bytes:
     """Use URL encoding to return an ASCII string
     corresponding to the given UTF8 string
 
+    ```python
     >>> hexify("http://example/a b")
     b'http://example/a%20b'
 
+    ```
     """
     # s1=ustr.encode('utf-8')
     s = ""
@@ -1988,8 +2003,7 @@ def hexify(ustr: str) -> bytes:
 
 
 class TurtleParser(Parser):
-    """
-    An RDFLib parser for Turtle
+    """An RDFLib parser for Turtle
 
     See http://www.w3.org/TR/turtle/
     """
@@ -2024,11 +2038,9 @@ class TurtleParser(Parser):
 
 
 class N3Parser(TurtleParser):
-    """
-    An RDFLib parser for Notation3
+    """An RDFLib parser for Notation3
 
     See http://www.w3.org/DesignIssues/Notation3.html
-
     """
 
     def __init__(self):
