@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
 """
-This serialiser will output an RDF Graph as a JSON-LD formatted document. See:
-
-    http://json-ld.org/
-
-Example usage::
+This serialiser will output an RDF Graph as a JSON-LD formatted document. See http://json-ld.org/
 
+Example:
+    ```python
     >>> from rdflib import Graph
     >>> testrdf = '''
     ... @prefix dc: <http://purl.org/dc/terms/> .
@@ -15,37 +12,41 @@ Example usage::
 
     >>> g = Graph().parse(data=testrdf, format='n3')
 
-    >>> print(g.serialize(format='json-ld', indent=4))
+    >>> print(g.serialize(format='json-ld', indent=2))
     [
-        {
-            "@id": "http://example.org/about",
-            "http://purl.org/dc/terms/title": [
-                {
-                    "@language": "en",
-                    "@value": "Someone's Homepage"
-                }
-            ]
-        }
+      {
+        "@id": "http://example.org/about",
+        "http://purl.org/dc/terms/title": [
+          {
+            "@language": "en",
+            "@value": "Someone's Homepage"
+          }
+        ]
+      }
     ]
 
+    ```
 """
+
 # From: https://github.com/RDFLib/rdflib-jsonld/blob/feature/json-ld-1.1/rdflib_jsonld/serializer.py
 
 # NOTE: This code writes the entire JSON object into memory before serialising,
 # but we should consider streaming the output to deal with arbitrarily large
 # graphs.
 
-import warnings
-from typing import IO, Optional
+from __future__ import annotations
 
-from rdflib.graph import Graph
+import warnings
+from typing import IO, Any, Dict, List, Optional
+
+from rdflib.graph import DATASET_DEFAULT_GRAPH_ID, Graph, _ObjectType
 from rdflib.namespace import RDF, XSD
 from rdflib.serializer import Serializer
-from rdflib.term import BNode, Literal, URIRef
+from rdflib.term import BNode, IdentifiedNode, Identifier, Literal, URIRef
 
 from ..shared.jsonld.context import UNDEF, Context
 from ..shared.jsonld.keys import CONTEXT, GRAPH, ID, LANG, LIST, SET, VOCAB
-from ..shared.jsonld.util import json
+from ..shared.jsonld.util import _HAS_ORJSON, json, orjson
 
 __all__ = ["JsonLDSerializer", "from_rdf"]
 
@@ -54,6 +55,8 @@ PLAIN_LITERAL_TYPES = {XSD.boolean, XSD.integer, XSD.double, XSD.string}
 
 
 class JsonLDSerializer(Serializer):
+    """JSON-LD RDF graph serializer."""
+
     def __init__(self, store: Graph):
         super(JsonLDSerializer, self).__init__(store)
 
@@ -62,8 +65,8 @@ class JsonLDSerializer(Serializer):
         stream: IO[bytes],
         base: Optional[str] = None,
         encoding: Optional[str] = None,
-        **kwargs,
-    ):
+        **kwargs: Any,
+    ) -> None:
         # TODO: docstring w. args and return value
         encoding = encoding or "utf-8"
         if encoding not in ("utf-8", "utf-16"):
@@ -89,16 +92,25 @@ class JsonLDSerializer(Serializer):
             use_rdf_type,
             auto_compact=auto_compact,
         )
-
-        data = json.dumps(
-            obj,
-            indent=indent,
-            separators=separators,
-            sort_keys=sort_keys,
-            ensure_ascii=ensure_ascii,
-        )
-
-        stream.write(data.encode(encoding, "replace"))
+        if _HAS_ORJSON:
+            option: int = orjson.OPT_NON_STR_KEYS
+            if indent is not None:
+                option |= orjson.OPT_INDENT_2
+            if sort_keys:
+                option |= orjson.OPT_SORT_KEYS
+            if ensure_ascii:
+                warnings.warn("Cannot use ensure_ascii with orjson")
+            data_bytes = orjson.dumps(obj, option=option)
+            stream.write(data_bytes)
+        else:
+            data = json.dumps(
+                obj,
+                indent=indent,
+                separators=separators,
+                sort_keys=sort_keys,
+                ensure_ascii=ensure_ascii,
+            )
+            stream.write(data.encode(encoding, "replace"))
 
 
 def from_rdf(
@@ -139,35 +151,53 @@ def from_rdf(
 
 
 class Converter:
-    def __init__(self, context, use_native_types, use_rdf_type):
+    def __init__(self, context: Context, use_native_types: bool, use_rdf_type: bool):
         self.context = context
         self.use_native_types = context.active or use_native_types
         self.use_rdf_type = use_rdf_type
 
-    def convert(self, graph):
+    def convert(self, graph: Graph):
         # TODO: bug in rdflib dataset parsing (nquads et al):
         # plain triples end up in separate unnamed graphs (rdflib issue #436)
         if graph.context_aware:
-            default_graph = Graph()
+            # type error: "Graph" has no attribute "contexts"
+            all_contexts = list(graph.contexts())  # type: ignore[attr-defined]
+            has_dataset_default_id = any(
+                c.identifier == DATASET_DEFAULT_GRAPH_ID for c in all_contexts
+            )
+            if (
+                has_dataset_default_id
+                # # type error: "Graph" has no attribute "contexts"
+                and graph.default_context.identifier == DATASET_DEFAULT_GRAPH_ID  # type: ignore[attr-defined]
+            ):
+                default_graph = graph.default_context  # type: ignore[attr-defined]
+            else:
+                default_graph = Graph()
             graphs = [default_graph]
-            for g in graph.contexts():
+            default_graph_id = default_graph.identifier
+
+            for g in all_contexts:
+                if g in graphs:
+                    continue
                 if isinstance(g.identifier, URIRef):
                     graphs.append(g)
                 else:
                     default_graph += g
         else:
             graphs = [graph]
+            default_graph_id = graph.identifier
 
         context = self.context
 
-        objs = []
+        objs: List[Any] = []
         for g in graphs:
             obj = {}
             graphname = None
 
             if isinstance(g.identifier, URIRef):
-                graphname = context.shrink_iri(g.identifier)
-                obj[context.id_key] = graphname
+                if g.identifier != default_graph_id:
+                    graphname = context.shrink_iri(g.identifier)
+                    obj[context.id_key] = graphname
 
             nodes = self.from_graph(g)
 
@@ -193,8 +223,8 @@ class Converter:
 
         return objs
 
-    def from_graph(self, graph):
-        nodemap = {}
+    def from_graph(self, graph: Graph):
+        nodemap: Dict[Any, Any] = {}
 
         for s in set(graph.subjects()):
             ## only iri:s and unreferenced (rest will be promoted to top if needed)
@@ -205,12 +235,13 @@ class Converter:
 
         return list(nodemap.values())
 
-    def process_subject(self, graph, s, nodemap):
+    def process_subject(self, graph: Graph, s: IdentifiedNode, nodemap):
         if isinstance(s, URIRef):
             node_id = self.context.shrink_iri(s)
         elif isinstance(s, BNode):
             node_id = s.n3()
         else:
+            # This does not seem right, this probably should be an error.
             node_id = None
 
         # used_as_object = any(graph.subjects(None, s))
@@ -222,11 +253,21 @@ class Converter:
         nodemap[node_id] = node
 
         for p, o in graph.predicate_objects(s):
-            self.add_to_node(graph, s, p, o, node, nodemap)
+            # type error: Argument 3 to "add_to_node" of "Converter" has incompatible type "Node"; expected "IdentifiedNode"
+            # type error: Argument 4 to "add_to_node" of "Converter" has incompatible type "Node"; expected "Identifier"
+            self.add_to_node(graph, s, p, o, node, nodemap)  # type: ignore[arg-type]
 
         return node
 
-    def add_to_node(self, graph, s, p, o, s_node, nodemap):
+    def add_to_node(
+        self,
+        graph: Graph,
+        s: IdentifiedNode,
+        p: IdentifiedNode,
+        o: Identifier,
+        s_node: Dict[str, Any],
+        nodemap,
+    ):
         context = self.context
 
         if isinstance(o, Literal):
@@ -237,7 +278,9 @@ class Converter:
             containers = [LIST, None] if graph.value(o, RDF.first) else [None]
             for container in containers:
                 for coercion in (ID, VOCAB, UNDEF):
-                    term = context.find_term(str(p), coercion, container)
+                    # type error: Argument 2 to "find_term" of "Context" has incompatible type "object"; expected "Union[str, Defined, None]"
+                    # type error: Argument 3 to "find_term" of "Context" has incompatible type "Optional[str]"; expected "Union[Defined, str]"
+                    term = context.find_term(str(p), coercion, container)  # type: ignore[arg-type]
                     if term:
                         break
                 if term:
@@ -251,10 +294,12 @@ class Converter:
 
             if term.type:
                 node = self.type_coerce(o, term.type)
-            elif term.language and o.language == term.language:
-                node = str(o)
-            elif context.language and (term.language is None and o.language is None):
+            # type error: "Identifier" has no attribute "language"
+            elif term.language and o.language == term.language:  # type: ignore[attr-defined]
                 node = str(o)
+            # type error: Right operand of "and" is never evaluated
+            elif context.language and (term.language is None and o.language is None):  # type: ignore[unreachable]
+                node = str(o)  # type: ignore[unreachable]
 
             if LIST in term.container:
                 node = [
@@ -301,7 +346,7 @@ class Converter:
             value = node
         s_node[p_key] = value
 
-    def type_coerce(self, o, coerce_type):
+    def type_coerce(self, o: Identifier, coerce_type: str):
         if coerce_type == ID:
             if isinstance(o, URIRef):
                 return self.context.shrink_iri(o)
@@ -316,7 +361,9 @@ class Converter:
         else:
             return None
 
-    def to_raw_value(self, graph, s, o, nodemap):
+    def to_raw_value(
+        self, graph: Graph, s: IdentifiedNode, o: Identifier, nodemap: Dict[str, Any]
+    ):
         context = self.context
         coll = self.to_collection(graph, o)
         if coll is not None:
@@ -347,26 +394,24 @@ class Converter:
             else:
                 v = str(o)
             if o.datatype:
-                if native:
-                    if self.context.active:
-                        return v
-                    else:
-                        return {context.value_key: v}
+                if native and self.context.active:
+                    return v
                 return {
                     context.type_key: context.to_symbol(o.datatype),
                     context.value_key: v,
                 }
             elif o.language and o.language != context.language:
                 return {context.lang_key: o.language, context.value_key: v}
-            elif not context.active or context.language and not o.language:
+            # type error: Right operand of "and" is never evaluated
+            elif not context.active or context.language and not o.language:  # type: ignore[unreachable]
                 return {context.value_key: v}
             else:
                 return v
 
-    def to_collection(self, graph, l_):
+    def to_collection(self, graph: Graph, l_: Identifier):
         if l_ != RDF.nil and not graph.value(l_, RDF.first):
             return None
-        list_nodes = []
+        list_nodes: List[Optional[_ObjectType]] = []
         chain = set([l_])
         while l_:
             if l_ == RDF.nil:
@@ -382,7 +427,8 @@ class Converter:
                 elif p != RDF.type or o != RDF.List:
                     return None
             list_nodes.append(first)
-            l_ = rest
+            # type error: Incompatible types in assignment (expression has type "Optional[Node]", variable has type "Identifier")
+            l_ = rest  # type: ignore[assignment]
             if l_ in chain:
                 return None
             chain.add(l_)
