@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
-#
 """
 This is an RDFLib store around Ivan Herman et al.'s SPARQL service wrapper.
 This was first done in layer-cake, and then ported to RDFLib
-
 """
+
+from __future__ import annotations
+
 import collections
 import re
 from typing import (
@@ -29,11 +29,12 @@ from rdflib.store import Store
 from rdflib.term import BNode, Identifier, Node, URIRef, Variable
 
 if TYPE_CHECKING:
-    import typing_extensions as te
+    import typing_extensions as te  # noqa: I001
     from rdflib.graph import (
         _TripleType,
         _ContextType,
         _QuadType,
+        _TripleChoiceType,
         _TriplePatternType,
         _SubjectType,
         _PredicateType,
@@ -55,14 +56,13 @@ BNODE_IDENT_PATTERN = re.compile(r"(?P<label>_\:[^\s]+)")
 _NodeToSparql = Callable[["Node"], str]
 
 
-def _node_to_sparql(node: "Node") -> str:
+def _node_to_sparql(node: Node) -> str:
     if isinstance(node, BNode):
         raise Exception(
             "SPARQLStore does not support BNodes! "
             "See http://www.w3.org/TR/sparql11-query/#BGPsparqlBNodes"
         )
-    # type error: "Node" has no attribute "n3"
-    return node.n3()  # type: ignore[attr-defined]
+    return node.n3()
 
 
 class SPARQLStore(SPARQLConnector, Store):
@@ -78,20 +78,23 @@ class SPARQLStore(SPARQLConnector, Store):
     motivated by the SPARQL 1.1.
 
     Fuseki/TDB has a flag for specifying that the default graph
-    is the union of all graphs (``tdb:unionDefaultGraph`` in the Fuseki config).
+    is the union of all graphs (`tdb:unionDefaultGraph` in the Fuseki config).
 
-    .. warning:: By default the SPARQL Store does not support blank-nodes!
+    !!! warning "Blank nodes
 
-                 As blank-nodes act as variables in SPARQL queries,
-                 there is no way to query for a particular blank node without
-                 using non-standard SPARQL extensions.
+        By default the SPARQL Store does not support blank-nodes!
 
-                 See http://www.w3.org/TR/sparql11-query/#BGPsparqlBNodes
+        As blank-nodes act as variables in SPARQL queries,
+        there is no way to query for a particular blank node without
+        using non-standard SPARQL extensions.
 
-    You can make use of such extensions through the ``node_to_sparql``
+        See http://www.w3.org/TR/sparql11-query/#BGPsparqlBNodes
+
+    You can make use of such extensions through the `node_to_sparql`
     argument. For example if you want to transform BNode('0001') into
     "<bnode:b0001>", you can use a function like this:
 
+    ```python
     >>> def my_bnode_ext(node):
     ...    if isinstance(node, BNode):
     ...        return '<bnode:b%s>' % node
@@ -99,10 +102,12 @@ class SPARQLStore(SPARQLConnector, Store):
     >>> store = SPARQLStore('http://dbpedia.org/sparql',
     ...                     node_to_sparql=my_bnode_ext)
 
+    ```
+
     You can request a particular result serialization with the
-    ``returnFormat`` parameter. This is a string that must have a
-    matching plugin registered. Built in is support for ``xml``,
-    ``json``, ``csv``, ``tsv`` and ``application/rdf+xml``.
+    `returnFormat` parameter. This is a string that must have a
+    matching plugin registered. Built in is support for `xml`,
+    `json`, `csv`, `tsv` and `application/rdf+xml`.
 
     The underlying SPARQLConnector uses the urllib library.
     Any extra kwargs passed to the SPARQLStore connector are passed to
@@ -111,10 +116,12 @@ class SPARQLStore(SPARQLConnector, Store):
 
     Form example:
 
+    ```python
     >>> store = SPARQLStore('...my endpoint ...', auth=('user','pass'))
 
-    will use HTTP basic auth.
+    ```
 
+    will use HTTP basic auth.
     """
 
     formula_aware = False
@@ -128,7 +135,7 @@ class SPARQLStore(SPARQLConnector, Store):
         sparql11: bool = True,
         context_aware: bool = True,
         node_to_sparql: _NodeToSparql = _node_to_sparql,
-        returnFormat: str = "xml",  # noqa: N803
+        returnFormat: Optional[str] = "xml",  # noqa: N803
         auth: Optional[Tuple[str, str]] = None,
         **sparqlconnector_kwargs,
     ):
@@ -147,11 +154,11 @@ class SPARQLStore(SPARQLConnector, Store):
         self._queries = 0
 
     # type error: Missing return statement
-    def open(self, configuration: str, create: bool = False) -> Optional[int]:  # type: ignore[return]
+    def open(self, configuration: Union[str, tuple[str, str]], create: bool = False) -> Optional[int]:  # type: ignore[return]
         """This method is included so that calls to this Store via Graph, e.g. Graph("SPARQLStore"),
         can set the required parameters
         """
-        if type(configuration) == str:
+        if type(configuration) is str:
             self.query_endpoint = configuration
         else:
             raise Exception(
@@ -175,31 +182,31 @@ class SPARQLStore(SPARQLConnector, Store):
         raise TypeError("The SPARQL store is read only")
 
     def add(
-        self, _: "_TripleType", context: "_ContextType" = None, quoted: bool = False
+        self, _: _TripleType, context: _ContextType = None, quoted: bool = False
     ) -> None:
         raise TypeError("The SPARQL store is read only")
 
-    def addN(self, quads: Iterable["_QuadType"]) -> None:  # noqa: N802
+    def addN(self, quads: Iterable[_QuadType]) -> None:  # noqa: N802
         raise TypeError("The SPARQL store is read only")
 
     # type error: Signature of "remove" incompatible with supertype "Store"
     def remove(  # type: ignore[override]
-        self, _: "_TriplePatternType", context: Optional["_ContextType"]
+        self, _: _TriplePatternType, context: Optional[_ContextType]
     ) -> None:
         raise TypeError("The SPARQL store is read only")
 
     # type error: Signature of "update" incompatible with supertype "SPARQLConnector"
     def update(  # type: ignore[override]
         self,
-        query: Union["Update", str],
+        query: Union[Update, str],
         initNs: Dict[str, Any] = {},  # noqa: N803
-        initBindings: Dict["str", "Identifier"] = {},
-        queryGraph: "Identifier" = None,
-        DEBUG: bool = False,
+        initBindings: Dict[str, Identifier] = {},  # noqa: N803
+        queryGraph: Identifier = None,  # noqa: N803
+        DEBUG: bool = False,  # noqa: N803
     ) -> None:
         raise TypeError("The SPARQL store is read only")
 
-    def _query(self, *args: Any, **kwargs: Any) -> "Result":
+    def _query(self, *args: Any, **kwargs: Any) -> Result:
         self._queries += 1
 
         return super(SPARQLStore, self).query(*args, **kwargs)
@@ -220,12 +227,12 @@ class SPARQLStore(SPARQLConnector, Store):
     # type error: Signature of "query" incompatible with supertype "Store"
     def query(  # type: ignore[override]
         self,
-        query: Union["Query", str],
+        query: Union[Query, str],
         initNs: Optional[Mapping[str, Any]] = None,  # noqa: N803
-        initBindings: Optional[Mapping["str", "Identifier"]] = None,
-        queryGraph: Optional["str"] = None,
-        DEBUG: bool = False,
-    ) -> "Result":
+        initBindings: Optional[Mapping[str, Identifier]] = None,  # noqa: N803
+        queryGraph: Optional[str] = None,  # noqa: N803
+        DEBUG: bool = False,  # noqa: N803
+    ) -> Result:
         self.debug = DEBUG
         assert isinstance(query, str)
 
@@ -249,8 +256,8 @@ class SPARQLStore(SPARQLConnector, Store):
 
     # type error: Return type "Iterator[Tuple[Tuple[Node, Node, Node], None]]" of "triples" incompatible with return type "Iterator[Tuple[Tuple[Node, Node, Node], Iterator[Optional[Graph]]]]"
     def triples(  # type: ignore[override]
-        self, spo: "_TriplePatternType", context: Optional["_ContextType"] = None
-    ) -> Iterator[Tuple["_TripleType", None]]:
+        self, spo: _TriplePatternType, context: Optional[_ContextType] = None
+    ) -> Iterator[Tuple[_TripleType, None]]:
         """
         - tuple **(s, o, p)**
           the triple used as filter for the SPARQL select.
@@ -268,22 +275,22 @@ class SPARQLStore(SPARQLConnector, Store):
         * OFFSET: an integer to enable paging of results
         * ORDERBY: an instance of Variable('s'), Variable('o') or Variable('p') or, by default, the first 'None' from the given triple
 
-        .. warning::
+        !!! warning "Limit and offset
 
             - Using LIMIT or OFFSET automatically include ORDERBY otherwise this is
               because the results are retrieved in a not deterministic way (depends on
               the walking path on the graph)
             - Using OFFSET without defining LIMIT will discard the first OFFSET - 1 results
 
-        .. code-block:: python
-
-            a_graph.LIMIT = limit
-            a_graph.OFFSET = offset
-            triple_generator = a_graph.triples(mytriple):
-            # do something
-            # Removes LIMIT and OFFSET if not required for the next triple() calls
-            del a_graph.LIMIT
-            del a_graph.OFFSET
+        ```python
+        a_graph.LIMIT = limit
+        a_graph.OFFSET = offset
+        triple_generator = a_graph.triples(mytriple):
+        # do something
+        # Removes LIMIT and OFFSET if not required for the next triple() calls
+        del a_graph.LIMIT
+        del a_graph.OFFSET
+        ```
         """
 
         s, p, o = spo
@@ -345,7 +352,7 @@ class SPARQLStore(SPARQLConnector, Store):
         )
 
         if vars:
-            if type(result) == tuple:
+            if type(result) is tuple:
                 if result[0] == 401:
                     raise ValueError(
                         "It looks like you need to authenticate with this SPARQL Store. HTTP unauthorized"
@@ -367,16 +374,12 @@ class SPARQLStore(SPARQLConnector, Store):
 
     def triples_choices(
         self,
-        _: Tuple[
-            Union["_SubjectType", List["_SubjectType"]],
-            Union["_PredicateType", List["_PredicateType"]],
-            Union["_ObjectType", List["_ObjectType"]],
-        ],
-        context: Optional["_ContextType"] = None,
+        _: _TripleChoiceType,
+        context: Optional[_ContextType] = None,
     ) -> Generator[
         Tuple[
-            Tuple["_SubjectType", "_PredicateType", "_ObjectType"],
-            Iterator[Optional["_ContextType"]],
+            Tuple[_SubjectType, _PredicateType, _ObjectType],
+            Iterator[Optional[_ContextType]],
         ],
         None,
         None,
@@ -390,7 +393,7 @@ class SPARQLStore(SPARQLConnector, Store):
         """
         raise NotImplementedError("Triples choices currently not supported")
 
-    def __len__(self, context: Optional["_ContextType"] = None) -> int:
+    def __len__(self, context: Optional[_ContextType] = None) -> int:
         if not self.sparql11:
             raise NotImplementedError(
                 "For performance reasons, this is not"
@@ -402,20 +405,22 @@ class SPARQLStore(SPARQLConnector, Store):
             result = self._query(
                 q,
                 # type error: Item "None" of "Optional[Graph]" has no attribute "identifier"
-                default_graph=context.identifier  # type: ignore[union-attr]
-                if self._is_contextual(context)
-                else None,
+                default_graph=(
+                    context.identifier  # type: ignore[union-attr]
+                    if self._is_contextual(context)
+                    else None
+                ),
             )
             # type error: Item "Tuple[Node, ...]" of "Union[Tuple[Node, Node, Node], bool, ResultRow]" has no attribute "c"
             return int(next(iter(result)).c)  # type: ignore[union-attr]
 
     # type error: Return type "Generator[Identifier, None, None]" of "contexts" incompatible with return type "Generator[Graph, None, None]" in supertype "Store"
     def contexts(  # type: ignore[override]
-        self, triple: Optional["_TripleType"] = None
-    ) -> Generator["_ContextIdentifierType", None, None]:
+        self, triple: Optional[_TripleType] = None
+    ) -> Generator[_ContextIdentifierType, None, None]:
         """
-        Iterates over results to "SELECT ?NAME { GRAPH ?NAME { ?s ?p ?o } }"
-        or "SELECT ?NAME { GRAPH ?NAME {} }" if triple is `None`.
+        Iterates over results to `SELECT ?NAME { GRAPH ?NAME { ?s ?p ?o } }`
+        or `SELECT ?NAME { GRAPH ?NAME {} }` if triple is `None`.
 
         Returns instances of this store with the SPARQL wrapper
         object updated via addNamedGraph(?NAME).
@@ -445,38 +450,36 @@ class SPARQLStore(SPARQLConnector, Store):
         return (row.name for row in result)  # type: ignore[union-attr,misc]
 
     # Namespace persistence interface implementation
-    def bind(self, prefix: str, namespace: "URIRef", override: bool = True) -> None:
+    def bind(self, prefix: str, namespace: URIRef, override: bool = True) -> None:
         bound_prefix = self.prefix(namespace)
         if override and bound_prefix:
             del self.nsBindings[bound_prefix]
         self.nsBindings[prefix] = namespace
 
-    def prefix(self, namespace: "URIRef") -> Optional["str"]:
+    def prefix(self, namespace: URIRef) -> Optional[str]:
         """ """
         return dict([(v, k) for k, v in self.nsBindings.items()]).get(namespace)
 
-    def namespace(self, prefix: str) -> Optional["URIRef"]:
+    def namespace(self, prefix: str) -> Optional[URIRef]:
         return self.nsBindings.get(prefix)
 
-    def namespaces(self) -> Iterator[Tuple[str, "URIRef"]]:
+    def namespaces(self) -> Iterator[Tuple[str, URIRef]]:
         for prefix, ns in self.nsBindings.items():
             yield prefix, ns
 
-    def add_graph(self, graph: "Graph") -> None:
+    def add_graph(self, graph: Graph) -> None:
         raise TypeError("The SPARQL store is read only")
 
-    def remove_graph(self, graph: "Graph") -> None:
+    def remove_graph(self, graph: Graph) -> None:
         raise TypeError("The SPARQL store is read only")
 
     @overload
-    def _is_contextual(self, graph: None) -> "te.Literal[False]":
-        ...
+    def _is_contextual(self, graph: None) -> te.Literal[False]: ...
 
     @overload
-    def _is_contextual(self, graph: Optional[Union["Graph", "str"]]) -> bool:
-        ...
+    def _is_contextual(self, graph: Optional[Union[Graph, str]]) -> bool: ...
 
-    def _is_contextual(self, graph: Optional[Union["Graph", "str"]]) -> bool:
+    def _is_contextual(self, graph: Optional[Union[Graph, str]]) -> bool:
         """Returns `True` if the "GRAPH" keyword must appear
         in the final SPARQL query sent to the endpoint.
         """
@@ -489,48 +492,48 @@ class SPARQLStore(SPARQLConnector, Store):
 
     def subjects(
         self,
-        predicate: Optional["_PredicateType"] = None,
-        object: Optional["_ObjectType"] = None,
-    ) -> Generator["_SubjectType", None, None]:
+        predicate: Optional[_PredicateType] = None,
+        object: Optional[_ObjectType] = None,
+    ) -> Generator[_SubjectType, None, None]:
         """A generator of subjects with the given predicate and object"""
         for t, c in self.triples((None, predicate, object)):
             yield t[0]
 
     def predicates(
         self,
-        subject: Optional["_SubjectType"] = None,
-        object: Optional["_ObjectType"] = None,
-    ) -> Generator["_PredicateType", None, None]:
+        subject: Optional[_SubjectType] = None,
+        object: Optional[_ObjectType] = None,
+    ) -> Generator[_PredicateType, None, None]:
         """A generator of predicates with the given subject and object"""
         for t, c in self.triples((subject, None, object)):
             yield t[1]
 
     def objects(
         self,
-        subject: Optional["_SubjectType"] = None,
-        predicate: Optional["_PredicateType"] = None,
-    ) -> Generator["_ObjectType", None, None]:
+        subject: Optional[_SubjectType] = None,
+        predicate: Optional[_PredicateType] = None,
+    ) -> Generator[_ObjectType, None, None]:
         """A generator of objects with the given subject and predicate"""
         for t, c in self.triples((subject, predicate, None)):
             yield t[2]
 
     def subject_predicates(
-        self, object: Optional["_ObjectType"] = None
-    ) -> Generator[Tuple["_SubjectType", "_PredicateType"], None, None]:
+        self, object: Optional[_ObjectType] = None
+    ) -> Generator[Tuple[_SubjectType, _PredicateType], None, None]:
         """A generator of (subject, predicate) tuples for the given object"""
         for t, c in self.triples((None, None, object)):
             yield t[0], t[1]
 
     def subject_objects(
-        self, predicate: Optional["_PredicateType"] = None
-    ) -> Generator[Tuple["_SubjectType", "_ObjectType"], None, None]:
+        self, predicate: Optional[_PredicateType] = None
+    ) -> Generator[Tuple[_SubjectType, _ObjectType], None, None]:
         """A generator of (subject, object) tuples for the given predicate"""
         for t, c in self.triples((None, predicate, None)):
             yield t[0], t[2]
 
     def predicate_objects(
-        self, subject: Optional["_SubjectType"] = None
-    ) -> Generator[Tuple["_PredicateType", "_ObjectType"], None, None]:
+        self, subject: Optional[_SubjectType] = None
+    ) -> Generator[Tuple[_PredicateType, _ObjectType], None, None]:
         """A generator of (predicate, object) tuples for the given subject"""
         for t, c in self.triples((subject, None, None)):
             yield t[1], t[2]
@@ -549,8 +552,7 @@ class SPARQLUpdateStore(SPARQLStore):
 
     For Graph objects, everything works as expected.
 
-    See the :class:`SPARQLStore` base class for more information.
-
+    See the [`SPARQLStore`][rdflib.plugins.stores.sparqlstore.SPARQLStore] base class for more information.
     """
 
     where_pattern = re.compile(r"""(?P<where>WHERE\s*\{)""", re.IGNORECASE)
@@ -621,13 +623,12 @@ class SPARQLUpdateStore(SPARQLStore):
         **kwds,
     ):
         """
-        :param autocommit if set, the store will commit after every
-        writing operations. If False, we only make queries on the
-        server once commit is called.
-
-        :param dirty_reads if set, we do not commit before reading. So you
-        cannot read what you wrote before manually calling commit.
-
+        Args:
+            autocommit: if set, the store will commit after every
+                writing operations. If False, we only make queries on the
+                server once commit is called.
+            dirty_reads if set, we do not commit before reading. So you
+                cannot read what you wrote before manually calling commit.
         """
 
         SPARQLStore.__init__(
@@ -645,25 +646,7 @@ class SPARQLUpdateStore(SPARQLStore):
         self._edits: Optional[List[str]] = None
         self._updates = 0
 
-    def open(
-        self, configuration: Union[str, Tuple[str, str]], create: bool = False
-    ) -> None:
-        """
-        This method is included so that calls to this Store via Graph, e.g.
-        Graph("SPARQLStore"), can set the required parameters
-        """
-        if type(configuration) == str:
-            self.query_endpoint = configuration
-        elif type(configuration) == tuple:
-            self.query_endpoint = configuration[0]
-            self.update_endpoint = configuration[1]
-        else:
-            raise Exception(
-                "configuration must be either a string (a single query endpoint URI) "
-                "or a tuple (a query/update endpoint URI pair)"
-            )
-
-    def query(self, *args: Any, **kwargs: Any) -> "Result":
+    def query(self, *args: Any, **kwargs: Any) -> Result:
         if not self.autocommit and not self.dirty_reads:
             self.commit()
         return SPARQLStore.query(self, *args, **kwargs)
@@ -671,7 +654,7 @@ class SPARQLUpdateStore(SPARQLStore):
     # type error: Signature of "triples" incompatible with supertype "Store"
     def triples(  # type: ignore[override]
         self, *args: Any, **kwargs: Any
-    ) -> Iterator[Tuple["_TripleType", None]]:
+    ) -> Iterator[Tuple[_TripleType, None]]:
         if not self.autocommit and not self.dirty_reads:
             self.commit()
         return SPARQLStore.triples(self, *args, **kwargs)
@@ -679,7 +662,7 @@ class SPARQLUpdateStore(SPARQLStore):
     # type error: Signature of "contexts" incompatible with supertype "Store"
     def contexts(  # type: ignore[override]
         self, *args: Any, **kwargs: Any
-    ) -> Generator["_ContextIdentifierType", None, None]:
+    ) -> Generator[_ContextIdentifierType, None, None]:
         if not self.autocommit and not self.dirty_reads:
             self.commit()
         return SPARQLStore.contexts(self, *args, **kwargs)
@@ -689,14 +672,15 @@ class SPARQLUpdateStore(SPARQLStore):
             self.commit()
         return SPARQLStore.__len__(self, *args, **kwargs)
 
-    # TODO: FIXME: open is defined twice
-    def open(self, configuration: Union[str, Tuple[str, str]], create: bool = False) -> None:  # type: ignore[no-redef]  # noqa: F811
-        """
-        sets the endpoint URLs for this SPARQLStore
+    def open(
+        self, configuration: Union[str, Tuple[str, str]], create: bool = False
+    ) -> None:
+        """Sets the endpoint URLs for this `SPARQLStore`
 
-        :param configuration: either a tuple of (query_endpoint, update_endpoint),
-            or a string with the endpoint which is configured as query and update endpoint
-        :param create: if True an exception is thrown.
+        Args:
+            configuration: either a tuple of (query_endpoint, update_endpoint),
+                or a string with the endpoint which is configured as query and update endpoint
+            create: if True an exception is thrown.
         """
 
         if create:
@@ -717,7 +701,7 @@ class SPARQLUpdateStore(SPARQLStore):
 
     # Transactional interfaces
     def commit(self) -> None:
-        """add(), addN(), and remove() are transactional to reduce overhead of many small edits.
+        """`add()`, `addN()`, and `remove()` are transactional to reduce overhead of many small edits.
         Read and update() calls will automatically commit any outstanding edits.
         This should behave as expected most of the time, except that alternating writes
         and reads can degenerate to the original call-per-triple situation that originally existed.
@@ -731,8 +715,8 @@ class SPARQLUpdateStore(SPARQLStore):
 
     def add(
         self,
-        spo: "_TripleType",
-        context: Optional["_ContextType"] = None,
+        spo: _TripleType,
+        context: Optional[_ContextType] = None,
         quoted: bool = False,
     ) -> None:
         """Add a triple to the store of triples."""
@@ -756,7 +740,7 @@ class SPARQLUpdateStore(SPARQLStore):
         if self.autocommit:
             self.commit()
 
-    def addN(self, quads: Iterable["_QuadType"]) -> None:  # noqa: N802
+    def addN(self, quads: Iterable[_QuadType]) -> None:  # noqa: N802
         """Add a list of quads to the store."""
         if not self.update_endpoint:
             raise Exception("UpdateEndpoint is not set - call 'open'")
@@ -781,7 +765,7 @@ class SPARQLUpdateStore(SPARQLStore):
 
     # type error: Signature of "remove" incompatible with supertype "Store"
     def remove(  # type: ignore[override]
-        self, spo: "_TriplePatternType", context: Optional["_ContextType"]
+        self, spo: _TriplePatternType, context: Optional[_ContextType]
     ) -> None:
         """Remove a triple from the store"""
         if not self.update_endpoint:
@@ -824,15 +808,14 @@ class SPARQLUpdateStore(SPARQLStore):
     # type error: Signature of "update" incompatible with supertype "Store"
     def update(  # type: ignore[override]
         self,
-        query: Union["Update", str],
+        query: Union[Update, str],
         initNs: Dict[str, Any] = {},  # noqa: N803
-        initBindings: Dict["str", "Identifier"] = {},
-        queryGraph: Optional[str] = None,
-        DEBUG: bool = False,
+        initBindings: Dict[str, Identifier] = {},  # noqa: N803
+        queryGraph: Optional[str] = None,  # noqa: N803
+        DEBUG: bool = False,  # noqa: N803
     ):
-        """
-        Perform a SPARQL Update Query against the endpoint,
-        INSERT, LOAD, DELETE etc.
+        """Perform a SPARQL Update Query against the endpoint, INSERT, LOAD, DELETE etc.
+
         Setting initNs adds PREFIX declarations to the beginning of
         the update. Setting initBindings adds inline VALUEs to the
         beginning of every WHERE clause. By the SPARQL grammar, all
@@ -842,25 +825,24 @@ class SPARQLUpdateStore(SPARQLStore):
         substring 'WHERE {' which does not denote a WHERE clause, e.g.
         if it is part of a literal.
 
-        .. admonition:: Context-aware query rewriting
+        !!! info "Context-aware query rewriting"
 
             - **When:**  If context-awareness is enabled and the graph is not the default graph of the store.
-            - **Why:** To ensure consistency with the :class:`~rdflib.plugins.stores.memory.Memory` store.
-              The graph must accept "local" SPARQL requests (requests with no GRAPH keyword)
-              as if it was the default graph.
+            - **Why:** To ensure consistency with the [`Memory`][rdflib.plugins.stores.memory.Memory] store.
+                The graph must accept "local" SPARQL requests (requests with no GRAPH keyword)
+                as if it was the default graph.
             - **What is done:** These "local" queries are rewritten by this store.
-              The content of each block of a SPARQL Update operation is wrapped in a GRAPH block
-              except if the block is empty.
-              This basically causes INSERT, INSERT DATA, DELETE, DELETE DATA and WHERE to operate
-              only on the context.
-            - **Example:** ``"INSERT DATA { <urn:michel> <urn:likes> <urn:pizza> }"`` is converted into
-              ``"INSERT DATA { GRAPH <urn:graph> { <urn:michel> <urn:likes> <urn:pizza> } }"``.
+                The content of each block of a SPARQL Update operation is wrapped in a GRAPH block
+                except if the block is empty.
+                This basically causes INSERT, INSERT DATA, DELETE, DELETE DATA and WHERE to operate
+                only on the context.
+            - **Example:** `"INSERT DATA { <urn:michel> <urn:likes> <urn:pizza> }"` is converted into
+                `"INSERT DATA { GRAPH <urn:graph> { <urn:michel> <urn:likes> <urn:pizza> } }"`.
             - **Warning:** Queries are presumed to be "local" but this assumption is **not checked**.
-              For instance, if the query already contains GRAPH blocks, the latter will be wrapped in new GRAPH blocks.
+                For instance, if the query already contains GRAPH blocks, the latter will be wrapped in new GRAPH blocks.
             - **Warning:** A simplified grammar is used that should tolerate
-              extensions of the SPARQL grammar. Still, the process may fail in
-              uncommon situations and produce invalid output.
-
+                extensions of the SPARQL grammar. Still, the process may fail in
+                uncommon situations and produce invalid output.
         """
         if not self.update_endpoint:
             raise Exception("Update endpoint is not set!")
@@ -894,12 +876,11 @@ class SPARQLUpdateStore(SPARQLStore):
             self.commit()
 
     def _insert_named_graph(self, query: str, query_graph: str) -> str:
-        """
-        Inserts GRAPH <query_graph> {} into blocks of SPARQL Update operations
+        """Inserts GRAPH <query_graph> {} into blocks of SPARQL Update operations
 
-        For instance,  "INSERT DATA { <urn:michel> <urn:likes> <urn:pizza> }"
+        For instance,  `INSERT DATA { <urn:michel> <urn:likes> <urn:pizza> }`
         is converted into
-        "INSERT DATA { GRAPH <urn:graph> { <urn:michel> <urn:likes> <urn:pizza> } }"
+        `INSERT DATA { GRAPH <urn:graph> { <urn:michel> <urn:likes> <urn:pizza> } }`
         """
         if isinstance(query_graph, Node):
             query_graph = self.node_to_sparql(query_graph)
@@ -950,13 +931,13 @@ class SPARQLUpdateStore(SPARQLStore):
 
         return "".join(modified_query)
 
-    def add_graph(self, graph: "Graph") -> None:
+    def add_graph(self, graph: Graph) -> None:
         if not self.graph_aware:
             Store.add_graph(self, graph)
         elif graph.identifier != DATASET_DEFAULT_GRAPH_ID:
             self.update("CREATE GRAPH %s" % self.node_to_sparql(graph.identifier))
 
-    def remove_graph(self, graph: "Graph") -> None:
+    def remove_graph(self, graph: Graph) -> None:
         if not self.graph_aware:
             Store.remove_graph(self, graph)
         elif graph.identifier == DATASET_DEFAULT_GRAPH_ID:
@@ -966,48 +947,51 @@ class SPARQLUpdateStore(SPARQLStore):
 
     def subjects(
         self,
-        predicate: Optional["_PredicateType"] = None,
-        object: Optional["_ObjectType"] = None,
-    ) -> Generator["_SubjectType", None, None]:
+        predicate: Optional[_PredicateType] = None,
+        object: Optional[_ObjectType] = None,
+    ) -> Generator[_SubjectType, None, None]:
         """A generator of subjects with the given predicate and object"""
         for t, c in self.triples((None, predicate, object)):
             yield t[0]
 
     def predicates(
         self,
-        subject: Optional["_SubjectType"] = None,
-        object: Optional["_ObjectType"] = None,
-    ) -> Generator["_PredicateType", None, None]:
+        subject: Optional[_SubjectType] = None,
+        object: Optional[_ObjectType] = None,
+    ) -> Generator[_PredicateType, None, None]:
         """A generator of predicates with the given subject and object"""
         for t, c in self.triples((subject, None, object)):
             yield t[1]
 
     def objects(
         self,
-        subject: Optional["_SubjectType"] = None,
-        predicate: Optional["_PredicateType"] = None,
-    ) -> Generator["_ObjectType", None, None]:
+        subject: Optional[_SubjectType] = None,
+        predicate: Optional[_PredicateType] = None,
+    ) -> Generator[_ObjectType, None, None]:
         """A generator of objects with the given subject and predicate"""
         for t, c in self.triples((subject, predicate, None)):
             yield t[2]
 
     def subject_predicates(
-        self, object: Optional["_ObjectType"] = None
-    ) -> Generator[Tuple["_SubjectType", "_PredicateType"], None, None]:
+        self, object: Optional[_ObjectType] = None
+    ) -> Generator[Tuple[_SubjectType, _PredicateType], None, None]:
         """A generator of (subject, predicate) tuples for the given object"""
         for t, c in self.triples((None, None, object)):
             yield t[0], t[1]
 
     def subject_objects(
-        self, predicate: Optional["_PredicateType"] = None
-    ) -> Generator[Tuple["_SubjectType", "_ObjectType"], None, None]:
+        self, predicate: Optional[_PredicateType] = None
+    ) -> Generator[Tuple[_SubjectType, _ObjectType], None, None]:
         """A generator of (subject, object) tuples for the given predicate"""
         for t, c in self.triples((None, predicate, None)):
             yield t[0], t[2]
 
     def predicate_objects(
-        self, subject: Optional["_SubjectType"] = None
-    ) -> Generator[Tuple["_PredicateType", "_ObjectType"], None, None]:
+        self, subject: Optional[_SubjectType] = None
+    ) -> Generator[Tuple[_PredicateType, _ObjectType], None, None]:
         """A generator of (predicate, object) tuples for the given subject"""
         for t, c in self.triples((subject, None, None)):
             yield t[1], t[2]
+
+
+__all__ = ["SPARQLUpdateStore", "SPARQLStore"]
