@@ -1,27 +1,28 @@
 """
-Testing with pytest
-=================
+# Testing with pytest
 
 This test runner uses pytest for test discovery and running. It uses the argument
 spec of pytest, but with some options pre-set. To begin with, make sure you have
 pytest installed, e.g.:
 
-    $ pip install pytest
+```bash
+poetry add pytest
+```
 
 To run the tests, use:
 
-    $ ./run_tests.py
+```bash
+./run_tests.py
+```
 
-For more details check <https://rdflib.readthedocs.io/en/stable/developers.html>.
+For more details check https://rdflib.readthedocs.io/en/stable/developers.html.
 
-Coverage
-========
+## Coverage
 
-If ``pytest-cov`` is placed in $PYTHONPATH, it can be used to create coverage
+If `pytest-cov` is placed in $PYTHONPATH, it can be used to create coverage
 information if the "--cov" option is supplied.
 
-See <https://github.com/pytest-dev/pytest-cov> for details.
-
+See https://github.com/pytest-dev/pytest-cov for details.
 """
 
 import json
