@@ -1,7 +1,7 @@
 from io import StringIO
 
-from rdflib import logger, plugin
-from rdflib.graph import ConjunctiveGraph, Graph, ReadOnlyGraphAggregate
+from rdflib import Dataset, Graph, logger, plugin
+from rdflib.graph import ReadOnlyGraphAggregate
 from rdflib.namespace import RDF, RDFS
 from rdflib.store import Store
 from rdflib.term import URIRef
@@ -108,10 +108,10 @@ def test_aggregate2():
 
     graph4 = Graph(mem_store, RDFS)
     graph4.parse(data=TEST_GRAPH_1N3, format="n3")
-    g = ConjunctiveGraph(mem_store)
+    g = Dataset(store=mem_store, default_union=True)
     assert g is not None
     assert len(list(g.quads((None, None, None, None)))) == 11
-    assert len(list(g.contexts())) == 4
+    assert len(list(g.contexts())) == 5
     logger.debug(list(g.contexts()))
     assert (
         len(list(g.quads((None, None, None, URIRef("http://example.com/graph2"))))) == 4
