@@ -75,3 +75,19 @@ def test_parse_berners_lee_card_into_graph():
     assert len(list(graph.subjects(unique=True))) == no_of_unique_subjects
     assert len(list(graph.predicates(unique=True))) == no_of_unique_predicates
     assert len(list(graph.objects(unique=True))) == no_of_unique_objects
+
+
+def test_subjects_multi():
+    graph = Graph()
+    add_stuff(graph)
+    assert len([subj for subj in graph.subjects(LIKES, [CHEESE, PIZZA])]) == 5
+    assert len([subj for subj in graph.subjects(LIKES, [])]) == 0
+    assert len([subj for subj in graph.subjects(LIKES | HATES, [CHEESE, PIZZA])]) == 6
+
+
+def test_objects_multi():
+    graph = Graph()
+    add_stuff(graph)
+    assert len([obj for obj in graph.objects([TAREK, BOB], LIKES)]) == 6
+    assert len([obj for obj in graph.objects([], LIKES)]) == 0
+    assert len([obj for obj in graph.objects([TAREK, BOB], LIKES | HATES)]) == 8
