@@ -1,13 +1,13 @@
 import itertools
 import os
-from test import TEST_DIR
 from urllib.error import URLError
 
 import pytest
 
-from rdflib.graph import ConjunctiveGraph, Graph
+from rdflib.graph import Dataset, Graph
 from rdflib.plugins.parsers.notation3 import BadSyntax, exponent_syntax
 from rdflib.term import Literal, URIRef
+from test import TEST_DIR
 
 test_data = """
 #  Definitions of terms describing the n3 model
@@ -44,7 +44,7 @@ n3:context      a rdf:Property; rdfs:domain n3:statement;
                 n3:predicate :p;
                 n3:object :y ] a log:Truth}.
 
-# Needs more thought ... ideally, we have the implcit AND rules of
+# Needs more thought ... ideally, we have the implicit AND rules of
 # juxtaposition (introduction and elimination)
 
 {
@@ -123,11 +123,13 @@ class TestN3Case:
                 URIRef("http://example.com/people/Linda"),
             )
         )
-        s = g.serialize(base="http://example.com/", format="n3", encoding="latin-1")
-        assert b"<people/Bob>" in s
-        g2 = ConjunctiveGraph()
-        g2.parse(data=s, publicID="http://example.com/", format="n3")
-        assert list(g) == list(g2)
+        s = g.serialize(
+            base="http://example.com/people/", format="n3", encoding="latin-1"
+        )
+        assert b"<Bob>" in s
+        g2 = Dataset()
+        g2.parse(data=s, format="n3")
+        assert list(g) == list(g2.triples((None, None, None)))
 
     def test_issue23(self):
         input = """<http://example.com/article1> <http://example.com/title> "this word is in \\u201Cquotes\\u201D"."""
@@ -195,24 +197,24 @@ foo-bar:Ex foo-bar:name "Test" . """
         )
 
     def test_model(self):
-        g = ConjunctiveGraph()
+        g = Dataset()
         g.parse(data=test_data, format="n3")
         i = 0
-        for s, p, o in g:
+        for s, p, o, c in g:
             if isinstance(s, Graph):
                 i += 1
         assert i == 3
-        assert len(list(g.contexts())) == 13
+        assert len(list(g.graphs())) == 13
 
         g.close()
 
     def test_quoted_serialization(self):
-        g = ConjunctiveGraph()
+        g = Dataset()
         g.parse(data=test_data, format="n3")
         g.serialize(format="n3")
 
     def test_parse(self):
-        g = ConjunctiveGraph()
+        g = Dataset()
         try:
             g.parse(
                 "http://groups.csail.mit.edu/dig/2005/09/rein/examples/troop42-policy.n3",
@@ -229,14 +231,14 @@ foo-bar:Ex foo-bar:name "Test" . """
 
         for data in test_data:
             # N3 doesn't accept single quotes around string literals
-            g = ConjunctiveGraph()
+            g = Dataset()
             with pytest.raises(BadSyntax):
                 g.parse(data=data, format="n3")
 
-            g = ConjunctiveGraph()
+            g = Dataset()
             g.parse(data=data, format="turtle")
             assert len(g) == 1
-            for _, _, o in g:
+            for _, _, o, c in g:
                 assert o == Literal("o")
 
     def test_empty_prefix(self):
@@ -251,6 +253,23 @@ foo-bar:Ex foo-bar:name "Test" . """
             g2
         ), "Document with declared empty prefix must match default #"
 
+    @pytest.mark.parametrize(
+        "do_normalize_literal, expected_result",
+        [(True, {"1.0", "10000000000.0"}), (False, {"1e10", "1e0"})],
+    )
+    def test_float_no_norm(self, do_normalize_literal, expected_result):
+        import rdflib
+
+        original_normalize_literal = rdflib.NORMALIZE_LITERALS
+        try:
+            rdflib.NORMALIZE_LITERALS = do_normalize_literal
+            g1 = Graph()
+            g1.parse(data=":a :b 1e10, 1e0 .", format="n3")
+            values = set(str(o) for o in g1.objects())
+            assert values == expected_result
+        finally:
+            rdflib.NORMALIZE_LITERALS = original_normalize_literal
+
 
 class TestRegularExpressions:
     def test_exponents(self):
