@@ -1,6 +1,6 @@
 import os
 
-from rdflib.graph import ConjunctiveGraph
+from rdflib.graph import Dataset
 from test.data import TEST_DATA_DIR
 
 
@@ -12,7 +12,7 @@ class TestTrixParse:
         pass
 
     def testAperture(self):  # noqa: N802
-        g = ConjunctiveGraph()
+        g = Dataset()
 
         trix_path = os.path.relpath(
             os.path.join(TEST_DATA_DIR, "suites", "trix/trix-aperture.trix"), os.curdir
@@ -24,12 +24,12 @@ class TestTrixParse:
         t = sum(map(len, g.contexts()))
 
         assert t == 24
-        assert len(c) == 4
+        assert len(c) == 5
 
         # print "Parsed %d triples"%t
 
     def testSpec(self):  # noqa: N802
-        g = ConjunctiveGraph()
+        g = Dataset()
 
         trix_path = os.path.relpath(
             os.path.join(TEST_DATA_DIR, "suites", "trix/trix-nokia-example.trix"),
@@ -40,7 +40,7 @@ class TestTrixParse:
         # print "Parsed %d triples"%len(g)
 
     def testNG4j(self):  # noqa: N802
-        g = ConjunctiveGraph()
+        g = Dataset()
 
         trix_path = os.path.relpath(
             os.path.join(TEST_DATA_DIR, "suites", "trix/trix-ng4j-test-01.trix"),
