@@ -1,7 +1,6 @@
-# -*- coding: UTF-8 -*-
 from io import BytesIO
 
-from rdflib.graph import ConjunctiveGraph
+from rdflib.graph import Dataset
 from rdflib.namespace import RDF, RDFS
 from rdflib.plugins.serializers.rdfxml import PrettyXMLSerializer
 from rdflib.term import BNode, Literal, URIRef
@@ -11,16 +10,16 @@ class SerializerTestBase:
     repeats = 8
 
     def setup_method(self):
-        graph = ConjunctiveGraph()
-        graph.parse(data=self.testContent, format=self.testContentFormat)
-        self.sourceGraph = graph
+        graph = Dataset()
+        graph.parse(data=self.test_content, format=self.test_content_format)
+        self.source_graph = graph
 
     def test_serialize_and_reparse(self):
-        reparsedGraph = serialize_and_load(self.sourceGraph, self.serializer)
-        _assert_equal_graphs(self.sourceGraph, reparsedGraph)
+        reparsed_graph = serialize_and_load(self.source_graph, self.serializer)
+        _assert_equal_graphs(self.source_graph, reparsed_graph)
 
     def test_multiple(self):
-        """Repeats ``test_serialize`` ``self.repeats`` times, to reduce sucess based on in-memory ordering."""
+        """Repeats `test_serialize` `self.repeats` times, to reduce sucess based on in-memory ordering."""
         for i in range(self.repeats):
             self.test_serialize_and_reparse()
 
@@ -41,13 +40,13 @@ _blank = BNode()
 
 
 def _mangled_copy(g):
-    "Makes a copy of the graph, replacing all bnodes with the bnode ``_blank``."
-    gcopy = ConjunctiveGraph()
+    "Makes a copy of the graph, replacing all bnodes with the bnode `_blank`."
+    gcopy = Dataset()
 
     def isbnode(v):
         return isinstance(v, BNode)
 
-    for s, p, o in g:
+    for s, p, o, c in g:
         if isbnode(s):
             s = _blank
         if isbnode(p):
@@ -58,25 +57,25 @@ def _mangled_copy(g):
     return gcopy
 
 
-def serialize(sourceGraph, makeSerializer, getValue=True, extra_args={}):
-    serializer = makeSerializer(sourceGraph)
+def serialize(source_graph, make_serializer, get_value=True, extra_args={}):
+    serializer = make_serializer(source_graph)
     stream = BytesIO()
     serializer.serialize(stream, **extra_args)
-    return getValue and stream.getvalue() or stream
+    return get_value and stream.getvalue() or stream
 
 
-def serialize_and_load(sourceGraph, makeSerializer):
-    stream = serialize(sourceGraph, makeSerializer, False)
+def serialize_and_load(source_graph, make_serializer):
+    stream = serialize(source_graph, make_serializer, False)
     stream.seek(0)
-    reparsedGraph = ConjunctiveGraph()
-    reparsedGraph.parse(stream, format="xml")
-    return reparsedGraph
+    reparsed_graph = Dataset()
+    reparsed_graph.parse(stream, format="xml")
+    return reparsed_graph
 
 
 class TestPrettyXmlSerializer(SerializerTestBase):
     serializer = PrettyXMLSerializer
 
-    testContent = """
+    test_content = """
         @prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
         @prefix owl:  <http://www.w3.org/2002/07/owl#> .
         @prefix : <http://example.org/model/test#> .
@@ -116,62 +115,62 @@ class TestPrettyXmlSerializer(SerializerTestBase):
             rdfs:seeAlso _:bnode2 .
 
         """
-    testContentFormat = "n3"
+    test_content_format = "n3"
 
     def test_result_fragments(self):
-        rdfXml = serialize(self.sourceGraph, self.serializer)
+        rdf_xml = serialize(self.source_graph, self.serializer)
         assert (
-            '<Test rdf:about="http://example.org/data/a">'.encode("latin-1") in rdfXml
+            '<Test rdf:about="http://example.org/data/a">'.encode("latin-1") in rdf_xml
         )
         assert (
             '<rdf:Description rdf:about="http://example.org/data/b">'.encode("latin-1")
-            in rdfXml
+            in rdf_xml
         )
-        assert '<name xml:lang="en">Bee</name>'.encode("latin-1") in rdfXml
+        assert '<name xml:lang="en">Bee</name>'.encode("latin-1") in rdf_xml
         assert (
             '<value rdf:datatype="http://www.w3.org/2001/XMLSchema#integer">3</value>'.encode(
                 "latin-1"
             )
-            in rdfXml
+            in rdf_xml
         )
         assert (
-            '<BNode rdf:nodeID="'.encode("latin-1") in rdfXml
+            '<BNode rdf:nodeID="'.encode("latin-1") in rdf_xml
         ), "expected one identified bnode in serialized graph"
         # onlyBNodesMsg = "expected only inlined subClassOf-bnodes in serialized graph"
-        # assert '<rdfs:subClassOf>' in rdfXml, onlyBNodesMsg
-        # assert not '<rdfs:subClassOf ' in rdfXml, onlyBNodesMsg
+        # assert '<rdfs:subClassOf>' in rdf_xml, onlyBNodesMsg
+        # assert not '<rdfs:subClassOf ' in rdf_xml, onlyBNodesMsg
 
     def test_result_fragments_with_base(self):
-        rdfXml = serialize(
-            self.sourceGraph,
+        rdf_xml = serialize(
+            self.source_graph,
             self.serializer,
             extra_args={
                 "base": "http://example.org/",
                 "xml_base": "http://example.org/",
             },
         )
-        assert 'xml:base="http://example.org/"'.encode("latin-1") in rdfXml
-        assert '<Test rdf:about="data/a">'.encode("latin-1") in rdfXml
-        assert '<rdf:Description rdf:about="data/b">'.encode("latin-1") in rdfXml
+        assert 'xml:base="http://example.org/"'.encode("latin-1") in rdf_xml
+        assert '<Test rdf:about="data/a">'.encode("latin-1") in rdf_xml
+        assert '<rdf:Description rdf:about="data/b">'.encode("latin-1") in rdf_xml
         assert (
             '<value rdf:datatype="http://www.w3.org/2001/XMLSchema#integer">3</value>'.encode(
                 "latin-1"
             )
-            in rdfXml
+            in rdf_xml
         )
         assert (
-            '<BNode rdf:nodeID="'.encode("latin-1") in rdfXml
+            '<BNode rdf:nodeID="'.encode("latin-1") in rdf_xml
         ), "expected one identified bnode in serialized graph"
 
-    def test_subClassOf_objects(self):
-        reparsedGraph = serialize_and_load(self.sourceGraph, self.serializer)
+    def test_subclass_of_objects(self):
+        reparsed_graph = serialize_and_load(self.source_graph, self.serializer)
         _assert_expected_object_types_for_predicates(
-            reparsedGraph, [RDFS.seeAlso, RDFS.subClassOf], [URIRef, BNode]
+            reparsed_graph, [RDFS.seeAlso, RDFS.subClassOf], [URIRef, BNode]
         )
 
     def test_pretty_xmlliteral(self):
         # given:
-        g = ConjunctiveGraph()
+        g = Dataset()
         g.add(
             (
                 BNode(),
@@ -192,7 +191,7 @@ class TestPrettyXmlSerializer(SerializerTestBase):
 
     def test_pretty_broken_xmlliteral(self):
         # given:
-        g = ConjunctiveGraph()
+        g = Dataset()
         g.add((BNode(), RDF.value, Literal("""<p """, datatype=RDF.XMLLiteral)))
         # when:
         xmlrepr = g.serialize(format="pretty-xml")
@@ -204,9 +203,9 @@ class TestPrettyXmlSerializer(SerializerTestBase):
 
 
 def _assert_expected_object_types_for_predicates(graph, predicates, types):
-    for s, p, o in graph:
+    for s, p, o, c in graph:
         if p in predicates:
-            someTrue = [isinstance(o, t) for t in types]
+            some_true = [isinstance(o, t) for t in types]
             assert (
-                True in someTrue
+                True in some_true
             ), "Bad type %s for object when predicate is <%s>." % (type(o), p)
