@@ -1,13 +1,9 @@
+from __future__ import annotations
+
 import logging
 import re
 import socket
 from http.server import BaseHTTPRequestHandler, HTTPServer
-from test.utils import helper
-from test.utils.httpservermock import (
-    MethodName,
-    MockHTTPResponse,
-    ServedBaseHTTPServerMock,
-)
 from threading import Thread
 from typing import Callable, ClassVar, Type
 from unittest.mock import patch
@@ -16,16 +12,18 @@ import pytest
 
 from rdflib import Graph, Literal, URIRef
 from rdflib.namespace import FOAF, RDF, RDFS, XMLNS, XSD
-from rdflib.plugins.stores.sparqlstore import SPARQLConnector
+from rdflib.plugins.stores.sparqlconnector import SPARQLConnector
+from test.utils import helper
+from test.utils.http import MethodName, MockHTTPResponse
+from test.utils.httpservermock import ServedBaseHTTPServerMock
 
 
 class TestSPARQLStoreGraph:
-    """
-    Tests for ``rdflib.Graph(store="SPARQLStore")``.
+    """SPARQLStore Graph Tests
 
-    .. note::
-        This is a pytest based test class to be used for new tests instead of
-        the older `unittest.TestCase` based classes.
+    !!! info "New Test Framework"
+        This is a pytest based test class that replaces the older
+        `unittest.TestCase` based classes for testing SPARQLStore functionality.
     """
 
     @pytest.mark.parametrize(
@@ -79,7 +77,7 @@ class TestSPARQLStoreFakeDBPedia:
     def teardown_method(self):
         self.graph.close()
 
-    def test_Query(self):
+    def test_query(self):
         query = "select distinct ?Concept where {[] a ?Concept} LIMIT 1"
         _query = SPARQLConnector.query
         self.httpmock.responses[MethodName.GET].append(
@@ -108,7 +106,7 @@ class TestSPARQLStoreFakeDBPedia:
             count = 0
             for i in res:
                 count += 1
-                assert type(i[0]) == URIRef, i[0].n3()
+                assert type(i[0]) is URIRef, i[0].n3()
             assert count > 0
             mock.assert_called_once()
             args, kwargs = mock.call_args
@@ -124,7 +122,7 @@ class TestSPARQLStoreFakeDBPedia:
         assert re.match(r"^/sparql", req.path)
         assert query in req.path_query["query"][0]
 
-    def test_initNs(self):
+    def test_init_ns(self):
         query = """\
         SELECT ?label WHERE
             { ?s a xyzzy:Concept ; xyzzy:prefLabel ?label . } LIMIT 10
@@ -170,9 +168,7 @@ class TestSPARQLStoreFakeDBPedia:
    <binding name="label"><literal xml:lang="en">1899–1900 in Belgian football</literal></binding>
   </result>
  </results>
-</sparql>""".encode(
-                    "utf8"
-                ),
+</sparql>""".encode(),
                 {"Content-Type": ["application/sparql-results+xml; charset=UTF-8"]},
             )
         )
@@ -180,14 +176,14 @@ class TestSPARQLStoreFakeDBPedia:
             query, initNs={"xyzzy": "http://www.w3.org/2004/02/skos/core#"}
         )
         for i in res:
-            assert type(i[0]) == Literal, i[0].n3()
+            assert type(i[0]) is Literal, i[0].n3()
 
         assert self.httpmock.mocks[MethodName.GET].call_count == 1
         req = self.httpmock.requests[MethodName.GET].pop(0)
         assert re.match(r"^/sparql", req.path)
         assert query in req.path_query["query"][0]
 
-    def test_noinitNs(self):
+    def test_noinit_ns(self):
         query = """\
         SELECT ?label WHERE
             { ?s a xyzzy:Concept ; xyzzy:prefLabel ?label . } LIMIT 10
@@ -260,15 +256,13 @@ SELECT ?label WHERE { ?s a xyzzy:Concept ; xyzzy:prefLabel ?label . } LIMIT 10""
    <binding name="label"><literal xml:lang="en">1899–1900 in Belgian football</literal></binding>
   </result>
  </results>
-</sparql>""".encode(
-                    "utf8"
-                ),
+</sparql>""".encode(),
                 {"Content-Type": ["application/sparql-results+xml; charset=UTF-8"]},
             )
         )
         res = helper.query_with_retry(self.graph, prologue + query)
         for i in res:
-            assert type(i[0]) == Literal, i[0].n3()
+            assert type(i[0]) is Literal, i[0].n3()
         assert self.httpmock.mocks[MethodName.GET].call_count == 1
         req = self.httpmock.requests[MethodName.GET].pop(0)
         assert re.match(r"^/sparql", req.path)
@@ -324,15 +318,13 @@ SELECT ?label WHERE { ?s a xyzzy:Concept ; xyzzy:prefLabel ?label . } LIMIT 10""
    <binding name="label"><literal xml:lang="en">1899–1900 in Belgian football</literal></binding>
   </result>
  </results>
-</sparql>""".encode(
-                    "utf8"
-                ),
+</sparql>""".encode(),
                 {"Content-Type": ["application/sparql-results+xml; charset=UTF-8"]},
             )
         )
         res = helper.query_with_retry(self.graph, prologue + query)
         for i in res:
-            assert type(i[0]) == Literal, i[0].n3()
+            assert type(i[0]) is Literal, i[0].n3()
         assert self.httpmock.mocks[MethodName.GET].call_count == 1
         req = self.httpmock.requests[MethodName.GET].pop(0)
         assert re.match(r"^/sparql", req.path)
@@ -352,7 +344,7 @@ SELECT ?label WHERE { ?s a xyzzy:Concept ; xyzzy:prefLabel ?label . } LIMIT 10""
         response = MockHTTPResponse(
             200,
             "OK",
-            """\
+            b"""\
         <sparql xmlns="http://www.w3.org/2005/sparql-results#" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.w3.org/2001/sw/DataAccess/rf1/result2.xsd">
         <head>
         <variable name="s"/>
@@ -374,9 +366,7 @@ SELECT ?label WHERE { ?s a xyzzy:Concept ; xyzzy:prefLabel ?label . } LIMIT 10""
         <binding name="s"><uri>http://www.openlinksw.com/virtrdf-data-formats#default-iid-nonblank</uri></binding>
         </result>
         </results>
-        </sparql>""".encode(
-                "utf8"
-            ),
+        </sparql>""",
             {"Content-Type": ["application/sparql-results+xml; charset=UTF-8"]},
         )
 
@@ -443,7 +433,7 @@ class TestSPARQLStoreUpdate:
     def teardown_method(self):
         self.graph.close()
 
-    def test_Query(self):
+    def test_query(self):
         query = "insert data {<urn:s> <urn:p> <urn:o>}"
         res = self.graph.update(query)
         print(res)
